@@ -22,7 +22,6 @@ from babeldoc.format.pdf.document_il.utils.formular_helper import is_formulas_st
 from babeldoc.format.pdf.document_il.utils.formular_helper import update_formula_data
 from babeldoc.format.pdf.document_il.utils.layout_helper import LEFT_BRACKET
 from babeldoc.format.pdf.document_il.utils.layout_helper import RIGHT_BRACKET
-from babeldoc.format.pdf.document_il.utils.layout_helper import build_layout_index
 from babeldoc.format.pdf.document_il.utils.layout_helper import calculate_iou_for_boxes
 from babeldoc.format.pdf.document_il.utils.layout_helper import (
     calculate_y_iou_for_boxes,
@@ -60,7 +59,6 @@ class StylesAndFormulas:
 
     def process_page(self, page: Page):
         """处理页面，包括公式识别和偏移量计算"""
-        build_layout_index(page)
         self.process_page_formulas(page)
         # self.process_page_offsets(page)
         self.process_comma_formulas(page)
@@ -72,10 +70,6 @@ class StylesAndFormulas:
         self.update_all_formula_data(page)
         self.process_page_styles(page)
 
-        # clean up to save memory
-        del page.layout_index
-        del page.layout_map
-
     def update_line_data(self, line: PdfLine):
         min_x = min(char.visual_bbox.box.x for char in line.pdf_character)
         min_y = min(char.visual_bbox.box.y for char in line.pdf_character)
@@ -815,15 +809,19 @@ class StylesAndFormulas:
         # 获取 formula1 中所有字符的 layout id
         formula1_layout_ids = set()
         for char in formula1.pdf_character:
+            if char.char_unicode == " ":
+                continue
             layout = char.formula_layout_id
-            if layout is not None:
+            if layout:
                 formula1_layout_ids.add(layout)
 
         # 获取 formula2 中所有字符的 layout id
         formula2_layout_ids = set()
         for char in formula2.pdf_character:
+            if char.char_unicode == " ":
+                continue
             layout = char.formula_layout_id
-            if layout is not None:
+            if layout:
                 formula2_layout_ids.add(layout)
 
         # 如果任一公式没有有效的 layout id，则不合并
